/*
 * Copyright 2011 Timothy Sparg
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.kilnhg.timsparg.juniorkilnclient.spi;

import com.kilnhg.timsparg.juniorkilndomain.KilnAPIError;
import com.kilnhg.timsparg.juniorkilndomain.KilnAPIErrorHolder;


/**
 *
 * @author Tim Sparg
 */
public class KilnClientException extends RuntimeException {

    private KilnAPIErrorHolder kilnAPIErrorHolder;

    public KilnClientException(String message) {
        super(message);
    }

    public KilnClientException(KilnAPIErrorHolder errorHolder) {
        super("Kiln API errors occoured");
        this.kilnAPIErrorHolder = errorHolder;
    }

    public KilnClientException(String message, Throwable t) {
        super(message, t);
    }

    public KilnAPIErrorHolder getKilnAPIErrorHolder() {
        return kilnAPIErrorHolder;
    }

    @Override
    public String getMessage() {
        if (kilnAPIErrorHolder == null || kilnAPIErrorHolder.getErrors() == null) {
            return super.getMessage();
        } else {
            StringBuilder errorBuilder = new StringBuilder();
            for (KilnAPIError kilnAPIError : kilnAPIErrorHolder.getErrors()) {
                errorBuilder.append(kilnAPIError);
                errorBuilder.append('\n');
            }

            return errorBuilder.toString() + super.getMessage();
        }
    }

    @Override
    public Throwable getCause() {
        if (kilnAPIErrorHolder == null && kilnAPIErrorHolder.getErrors() == null
                && kilnAPIErrorHolder.getErrors().size() > 0 && this.getCause() == null) {
            return getKilnAPIErrorHolder().getErrors().get(0);
        } else {
            return super.getCause();
        }
    }
}
